@@ -3,7 +3,7 @@ use feature ':5.10';
 use strict;
 use warnings;
 
-our $VERSION = "0.02";
+our $VERSION = "0.03";
 use Acme::Want5000trillion::Asciiart;
 
 my $languages = {
@@ -12,13 +12,12 @@ my $languages = {
     "th" => "ฉันต้องการ 5000000000000000 เยน!",
     "cn" => "我想五千万亿日元!",
     "it" => "Voglio 5000 trilioni di yen!",
-    "aa" => "&Acme::Want5000trillion::Asciiart::sayAA()",
+    "aa" => Acme::Want5000trillion::Asciiart::sayAA(),
 };
 
 
 sub say{
     my ($self,$lang) = @_;
-    
     $lang //= "ja";
     $lang = "ja" if (! exists($languages->{$lang}));
     return "$languages->{$lang}";
@@ -50,7 +49,7 @@ Acme::Want5000trillion - I want 5000trillion yen.
 
     print $want->say(); #5000兆円欲しい!
     print $want->say('en'); #I want 5000 trillion yen!
-
+    print $want->say('aa'); # print AA
 
 =head1 DESCRIPTION
 
@@ -59,6 +58,9 @@ I want 5000 trillion yen.
 
 This module correspondence some languages.
 
+This module consepts that illutstlation.
+https://www.pixiv.net/member_illust.php?mode=medium&illust_id=62495210
+
 =over
 
 =item  ja 
